Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(166)

Unified Diff: chrome/browser/ui/cocoa/tabs/tab_strip_controller.h

Issue 2489373002: [Mac] (More) RTL support for tab strip (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/tabs/tab_strip_controller.h
diff --git a/chrome/browser/ui/cocoa/tabs/tab_strip_controller.h b/chrome/browser/ui/cocoa/tabs/tab_strip_controller.h
index 1161e5fdb535e0dc84479a9ef41d05dd11edf4e0..a9566eaa202917f1ddb45ffeb5761a86f9438b2f 100644
--- a/chrome/browser/ui/cocoa/tabs/tab_strip_controller.h
+++ b/chrome/browser/ui/cocoa/tabs/tab_strip_controller.h
@@ -143,8 +143,8 @@ class WebContents;
// The amount by which to indent the tabs on the sides (to make room for the
// red/yellow/green and incognito/fullscreen buttons).
- CGFloat leftIndentForControls_;
- CGFloat rightIndentForControls_;
+ CGFloat leadingIndentForControls_;
+ CGFloat trailingIndentForControls_;
// Is the mouse currently inside the strip;
BOOL mouseInside_;
@@ -158,8 +158,8 @@ class WebContents;
base::scoped_nsobject<CrTrackingArea> customWindowControlsTrackingArea_;
}
-@property(nonatomic) CGFloat leftIndentForControls;
-@property(nonatomic) CGFloat rightIndentForControls;
+@property(nonatomic) CGFloat leadingIndentForControls;
+@property(nonatomic) CGFloat trailingIndentForControls;
@property(assign, nonatomic) TabView* hoveredTab;
@@ -265,8 +265,8 @@ class WebContents;
// Default height for tabs.
+ (CGFloat)defaultTabHeight;
-// Default indentation for tabs (see |leftIndentForControls_|).
-+ (CGFloat)defaultLeftIndentForControls;
+// Default indentation for tabs (see |leadingIndentForControls_|).
++ (CGFloat)defaultLeadingIndentForControls;
// Returns the amount by which tabs overlap.
+ (CGFloat)tabOverlap;
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_layout_unittest.mm ('k') | chrome/browser/ui/cocoa/tabs/tab_strip_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698